SWDEV-339657 - Update catch codes with correct coordinates (#2735)

Change-Id: I8ca78d770a742bf6c2abede494759caa923fcc19
Cette révision appartient à :
ROCm CI Service Account
2022-06-15 23:28:10 +05:30
révisé par GitHub
Parent 0b05268be2
révision d31aca651d
8 fichiers modifiés avec 19 ajouts et 19 suppressions
+1 -1
Voir le fichier
@@ -57,7 +57,7 @@ Testcase Scenarios :
* Kernel Functions to copy.
*/
static __global__ void copy_ker_func(int* a, int* b) {
int tx = hipBlockIdx_x*hipBlockDim_x + hipThreadIdx_x;
int tx = blockIdx.x*blockDim.x + threadIdx.x;
if (tx < LEN) b[tx] = a[tx];
}